@@ -10,7 +10,7 @@ use IO::Socket;
 use IO::Socket::SSL;
 use Time::Crontab;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 sub new {
     my $class = shift;
@@ -58,6 +58,7 @@ sub run {
     eval {
         $self->{device} = Daemon::Device->new(
             parent     => \&_parent,
+            child      => \&_child,
             on_message => \&_on_message,
             spawn      => $self->{spawn},
             daemon     => $self->{daemon},
@@ -94,6 +95,8 @@ sub _parent {
         );
     };
 
+    srand();
+
     eval {
         while ( my $line = $self->{socket}->getline ) {
             print $line;
@@ -121,10 +124,15 @@ sub _parent {
             $delegate->($line);
         }
     };
-
+    warn "$@\n";
     kill( 'KILL', $_ ) for ( @{ $device->children } );
 }
 
+sub _child {
+    srand();
+    sleep 1 while (1);
+}
+
 sub _on_message {
     my $device = shift;
     my $self   = $device->data('self');
@@ -231,14 +239,14 @@ sub load {
         unless ( ref $plugin ) {
             if ( $plugin =~ /^:core$/i ) {
                 $self->load(
+                    'Join',
+                    'Seen',
+                    'Greeting',
                     'Infobot',
                     'Functions',
                     'Convert',
-                    'Join',
-                    'Seen',
                     'Karma',
                     'Math',
-                    'Greeting',
                 );
                 next;
             }
@@ -452,7 +460,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC)
