@@ -4,7 +4,7 @@ package Bot::IRC::Functions;
 use strict;
 use warnings;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -16,7 +16,7 @@ sub init {
     $bot->hook(
         {
             command => 'PRIVMSG',
-            text    => qr/(?<function>ord|chr|ascii|rot\d+|crypt)\s+(?<input>.+)/i,
+            text    => qr/^(?<function>ord|chr|ascii|rot\d+|crypt)\s+(?<input>.+)/i,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -73,7 +73,7 @@ Bot::IRC::Functions - Bot::IRC add maybe helpful functions to the bot
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
