@@ -7,7 +7,7 @@ use warnings;
 use DateTime;
 use DateTime::Format::Human::Duration;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -16,7 +16,7 @@ sub init {
     $bot->hook(
         {
             command => 'PRIVMSG',
-            text    => qr/(?<term>\([^\)]+\)|\S+)\s+(?:is|=)\s+(?<fact>.+?)$/i,
+            text    => qr/^(?<term>\([^\)]+\)|\S+)\s+(?:is|=)\s+(?<fact>.+?)$/i,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -34,7 +34,7 @@ sub init {
     $bot->hook(
         {
             command => 'PRIVMSG',
-            text    => qr/^\s*(?<term>\([^\)]+\)|\S+)\?/i,
+            text    => qr/^(?<term>\([^\)]+\)|\S+)\?/i,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -61,7 +61,7 @@ sub init {
             }
             $bot->reply(
                 $text //
-                "$display_term is " . $bot->list( ', ', 'and', map { /[.,;:?!]+$/; $_ } @facts ) . '.'
+                "$display_term is " . $bot->list( ', ', 'and', map { s/[.,;:?!]+$//; $_ } @facts ) . '.'
             );
         },
     );
@@ -69,7 +69,7 @@ sub init {
     $bot->hook(
         {
             to_me => 1,
-            text  => qr/no\W+(?<term>\([^\)]+\)|\S+)\s+(?:is|=)\s+(?<fact>.+?)[.,:;?!]*$/i,
+            text  => qr/^no\W+(?<term>\([^\)]+\)|\S+)\s+(?:is|=)\s+(?<fact>.+?)$/i,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -84,7 +84,7 @@ sub init {
     $bot->hook(
         {
             to_me => 1,
-            text  => qr/forget\W+(?<term>\([^\)]+\)|\S+)/i,
+            text  => qr/^forget\W+(?<term>\([^\)]+\)|[^.,:;?!\s]+)/i,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -99,7 +99,7 @@ sub init {
     $bot->hook(
         {
             to_me => 1,
-            text  => qr/info\s+on\s+(?<term>\([^\)]+\)|\S+)/i,
+            text  => qr/^info\s+on\s+(?<term>\([^\)]+\)|[^.,:;?!\s]+)/i,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -135,7 +135,7 @@ Bot::IRC::Infobot - Bot::IRC add classic "infobot" functionality to the bot
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
