@@ -4,7 +4,7 @@ package Bot::IRC::Join;
 use strict;
 use warnings;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -13,7 +13,7 @@ sub init {
     $bot->hook(
         {
             to_me => 1,
-            text  => qr/\bjoin\s+(?<channel>\S+)/i,
+            text  => qr/^join\s+(?<channel>\S+)/i,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -31,7 +31,7 @@ sub init {
     $bot->hook(
         {
             to_me => 1,
-            text  => qr/\b(?:part|leave)\s+(?<channel>\S+)/i,
+            text  => qr/^(?:part|leave)\s+(?<channel>\S+)/i,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -49,11 +49,11 @@ sub init {
     $bot->hook(
         {
             to_me => 1,
-            text  => qr/\bchannels\b/i,
+            text  => qr/^channels\b/i,
         },
         sub {
             my ($bot)    = @_;
-            my @channels = @{ $bot->store->get('join') || [] };
+            my @channels = @{ $bot->store->get('channels') || [] };
 
             $bot->reply_to(
                 (@channels)
@@ -125,7 +125,7 @@ Bot::IRC::Join - Bot::IRC join and part channels and remember channels state
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
