@@ -4,7 +4,7 @@ package Bot::IRC::Karma;
 use strict;
 use warnings;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -13,7 +13,7 @@ sub init {
     $bot->hook(
         {
             command => 'PRIVMSG',
-            text    => qr/(?<thing>\([^\)]+\)|\S+)\s*(?<type>[+-]{2,})(?:\s*#\s*(?<comment>.+))?/,
+            text    => qr/^(?<thing>\([^\)]+\)|\S+)\s*(?<type>[+-]{2,})(?:\s*#\s*(?<comment>.+))?/,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -29,14 +29,13 @@ sub init {
 
             push( @{ $thing->{comments}{$type} }, $m->{comment} ) if ( $m->{comment} );
             $bot->store->set( lc( $m->{thing} ) => $thing );
-            return;
         },
     );
 
     $bot->hook(
         {
             to_me => 1,
-            text  => qr/\bkarma\s+(?<thing>\([^\)]+\)|\S+)/i,
+            text  => qr/^karma\s+(?<thing>\([^\)]+\)|\S+)/i,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -50,7 +49,7 @@ sub init {
     $bot->hook(
         {
             to_me => 1,
-            text  => qr/\bexplain\s+(?<thing>\([^\)]+\)|\S+)/i,
+            text  => qr/^explain\s+(?<thing>\([^\)]+\)|\S+)/i,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -91,7 +90,7 @@ Bot::IRC::Karma - Bot::IRC track karma for things
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
