@@ -7,7 +7,7 @@ use warnings;
 use DateTime;
 use DateTime::Format::Human::Duration;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -30,7 +30,7 @@ sub init {
     $bot->hook(
         {
             to_me => 1,
-            text  => qr/\bseen\s+(?<nick>\S+)/i,
+            text  => qr/^seen\s+(?<nick>\S+)/i,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -67,7 +67,7 @@ Bot::IRC::Seen - Bot::IRC track when and where users were last seen
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
